'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _generatePot = require('./commands/generate-pot');

var _generatePot2 = _interopRequireDefault(_generatePot);

var _generateReadmeMd = require('./commands/generate-readme-md');

var _generateReadmeMd2 = _interopRequireDefault(_generateReadmeMd);

var _info = require('./commands/info');

var _info2 = _interopRequireDefault(_info);

var _init = require('./commands/init');

var _init2 = _interopRequireDefault(_init);

var _releaseGh = require('./commands/release-gh');

var _releaseGh2 = _interopRequireDefault(_releaseGh);

var _releaseWporg = require('./commands/release-wporg');

var _releaseWporg2 = _interopRequireDefault(_releaseWporg);

var _validateI18n = require('./commands/validate-i18n');

var _validateI18n2 = _interopRequireDefault(_validateI18n);

var _validateReadmeTxt = require('./commands/validate-readme-txt');

var _validateReadmeTxt2 = _interopRequireDefault(_validateReadmeTxt);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Internal dependencies
 */
var branchOption = ['-b, --branch <branch>', 'Git release branch. Default to master.'];
var mainFileOption = ['-f, --file <file>', 'Plugin main file.'];
var projectTypeOption = ['-t, --type <type>', 'Project type (plugin or theme).'];
var quietOption = ['-q, --quiet', 'Disable all output.'];

exports.default = {
	'generate:pot': {
		description: 'Generate POT.',
		options: [mainFileOption, projectTypeOption, quietOption],
		action: function action(args, config) {
			(0, _generatePot2.default)(args, config);
		}
	},
	'generate:readme-md': {
		description: 'Generate README.md from readme.txt.',
		options: [quietOption],
		action: function action(args) {
			(0, _generateReadmeMd2.default)(args);
		}
	},
	info: {
		description: 'View plugin/theme project info.',
		options: [mainFileOption, projectTypeOption],
		action: function action(args, config) {
			(0, _info2.default)(args, config);
		}
	},
	init: {
		description: 'Initialize .wpt.yaml.',
		longDescription: 'If .wpt.yml exists in current directory, it will read ' + 'that first, and default to the options there.',
		options: [['-d, --use-defaults', 'Use only defaults and not prompt you for any options.']],
		action: function action(args, config) {
			(0, _init2.default)(args, config);
		}
	},
	'release:gh': {
		description: 'Release the project to GitHub.',
		longDescription: ['This command will do the following actions:', '', '  1) Checkout to the branch `--branch` if specified or `gh.branch`', '     in .wpt.yml. Otherwise checkout to the `master` branch.', '  2) Check if there are uncommitted changes. If yes stop.', '  3) Push the changes to the remote origin.', '  4) Create the tag from version number found in plugin/theme main', '     file as defined in `files.main` of .wpt.yml.', '  5) Push the tag.', '  6) Create the release based on created tag. By default the release', '     is published one unless `--draft` and/or `--pre-release` is', '     specified. GitHub token needs to be specified either via `--token`', '     or `WPT_GITHUB_TOKEN` environment variable.'].join('\n'),
		options: [branchOption, ['-d, --draft', 'Create a draft.'], mainFileOption, ['-p, --pre-release', 'Release as a prerelease.'], quietOption, ['-r, --repo <repo>', 'GitHub repo with format "owner/repo".'], ['-t, --token <token>', 'GitHub token.']],
		action: function action(args, config) {
			(0, _releaseGh2.default)(args, config);
		}
	},
	'release:wporg': {
		description: 'Release the project to WP.org.',
		options: [branchOption, ['-s, --slug <slug>', 'WP.org slug. Default to value in .wpt.yml.'], ['-u, --username', 'WP.org username. Default to value in .wpt.yml.'], ['-b, --build-path <path>', 'Path to build directory.'], ['-i, --ignore <files>', 'Ignored files.']],
		action: function action(args, config) {
			(0, _releaseWporg2.default)(args, config);
		}
	},
	'validate:i18n': {
		description: 'Check your code for incorrect text-domain.',
		requireConfigFile: true,
		options: [mainFileOption],
		action: function action(args, config) {
			(0, _validateI18n2.default)(args, config);
		}
	},
	'validate:readme-txt': {
		description: 'Check your readme.txt.',
		action: function action(args, config) {
			(0, _validateReadmeTxt2.default)(args, config);
		}
	}
};
module.exports = exports['default'];