'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }(); /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          * External dependencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          */


/**
 * Internal dependencies
 */


var _parseGithubRepoUrl = require('parse-github-repo-url');

var _parseGithubRepoUrl2 = _interopRequireDefault(_parseGithubRepoUrl);

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _fileHeader = require('../utils/file-header');

var _fileHeader2 = _interopRequireDefault(_fileHeader);

var _git = require('../utils/git');

var _git2 = _interopRequireDefault(_git);

var _logger = require('../utils/logger');

var _logger2 = _interopRequireDefault(_logger);

var _readme = require('../utils/readme');

var _readme2 = _interopRequireDefault(_readme);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = function (args, config) {
	var params = void 0;
	try {
		params = getParams(args, config);

		getReleaseActions().forEach(function (action) {
			action(params);
		});
	} catch (e) {
		_logger2.default.error(e.toString());
	}

	afterRelease(params);
};

function getParams(args, config) {
	var files = config.files || {};
	var mainFile = args.file || files.main;
	var type = args.type || config.type || 'plugin';
	var gh = config.gh || {};
	var repo = args.repo || gh.repo;
	if (!repo) {
		throw new Error('Missing GitHub repo. Specify it via --repo or define `gh.repo` in .wpt.yml.');
	}

	var repoParsed = (0, _parseGithubRepoUrl2.default)(repo);
	if (!Array.isArray(repoParsed)) {
		throw new Error('Invalid gh.repo value, the format is "owner/repo"');
	}

	var _repoParsed = _slicedToArray(repoParsed, 2),
	    repoOwner = _repoParsed[0],
	    repoName = _repoParsed[1];

	var originalBranch = _git2.default.getCurrentBranch();
	var branch = args.branch || gh.branch || 'master';
	var token = args.token || process.env.WPT_GITHUB_TOKEN;

	var data = _fileHeader2.default.getFileData(mainFile, type);
	var version = data.Version;
	var changelog = _readme2.default.getChangelog(version);

	var draft = !!args.draft;
	var preRelease = !!args.preRelease;

	return {
		repoOwner: repoOwner,
		repoName: repoName,
		token: token,
		version: version,
		originalBranch: originalBranch,
		branch: branch,
		changelog: changelog,
		draft: draft,
		preRelease: preRelease
	};
}

function getReleaseActions() {
	return [switchGitBranch, checkBeforePush, gitPush, ghRelease];
}

function switchGitBranch(params) {
	_logger2.default.info('switch to branch ' + params.branch);
	_git2.default.checkout(params.branch);
}

function checkBeforePush(params) {
	_logger2.default.info('check uncommitted changes');
	_git2.default.checkUncommittedChanges();

	_logger2.default.info('check version in readme.txt');
	_readme2.default.checkVersion(params.version);
}

function gitPush(params) {
	_logger2.default.info('push changes to remote origin');
	_git2.default.push(params.branch);

	_logger2.default.info('create tag ' + params.version);
	_git2.default.tag(params.version);

	_logger2.default.info('push tag to remote origin');
	_git2.default.pushTag(params.version);
}

function afterRelease(params) {
	try {
		_logger2.default.info('switch back to ' + params.originalBranch);
		_git2.default.checkout(params.originalBranch);
	} catch (e) {}
}

function ghRelease(params) {
	var req = {
		method: 'POST',
		url: getReleaseUrl(params),
		headers: {
			'Authorization': 'token ' + params.token, // eslint-disable-line quote-props
			'User-Agent': 'gedex/wpt'
		},
		body: getReleaseBody(params),
		json: true
	};
	var cb = function cb(err, resp, body) {
		var args = [err, resp, body, req];
		checkResult.apply(undefined, args);
	};

	_logger2.default.info('create GitHub release ' + params.version);
	(0, _request2.default)(req, cb);
}

function getReleaseUrl(params) {
	if (!params.repoOwner || !params.repoName) {
		throw new Error('Missing GitHub repo. Please specify it via --repo or define gh.repo with format "owner/repo" in .wpt.yml');
	}

	return 'https://api.github.com/repos/' + params.repoOwner + '/' + params.repoName + '/releases';
}

function getReleaseBody(params) {
	return {
		tag_name: params.version, // eslint-disable-line camelcase
		name: params.version,
		body: params.changelog,
		draft: params.draft,
		prerelease: params.preRelease
	};
}

function checkResult() {
	try {
		for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
			args[_key] = arguments[_key];
		}

		checkError.apply(undefined, args);

		var body = args[2];

		_logger2.default.success('GitHub release is created: ' + body.html_url);
	} catch (e) {
		_logger2.default.error(e.toString());
	}
}

function checkError() {
	for (var _len2 = arguments.length, args = Array(_len2), _key2 = 0; _key2 < _len2; _key2++) {
		args[_key2] = arguments[_key2];
	}

	var err = args[0],
	    resp = args[1],
	    body = args[2],
	    req = args[3];

	if (err) {
		throw new Error(err.message);
	}

	var errInfo = ['Request options:', JSON.stringify(req, null, 2) + '\n', 'Response:', JSON.stringify(resp, null, 2) + '\n', 'If this seems like a bug, please report new issue at:', 'https://github.com/gedex/wp-tools/issues'].join('\n');

	switch (resp.statusCode) {
		case 400:
			throw new Error('Bad request.\n\n' + errInfo);
		case 401:
			throw new Error('Invalid token.\n\n' + errInfo);
		case 422:
			var errors = body.errors || [];
			errors.forEach(function (error) {
				if ('already_exists' === error.code) {
					throw new Error('Release ' + req.body.tag_name + ' already exists.');
				}
			});
		default:
			if (201 === resp.statusCode) {
				break;
			}
			throw new Error('Unexpected status code ' + resp.statusCode + '.\n\n' + errInfo);
	}
}
module.exports = exports['default'];