'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _cheerio = require('cheerio');

var _cheerio2 = _interopRequireDefault(_cheerio);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _request = require('request');

var _request2 = _interopRequireDefault(_request);

var _dir = require('../utils/dir');

var _dir2 = _interopRequireDefault(_dir);

var _logger = require('../utils/logger');

var _logger2 = _interopRequireDefault(_logger);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Internal dependencies
 */
exports.default = function () {
	try {
		var readme = _fs2.default.readFileSync(_dir2.default.getReadmeTxtPath(), 'utf8');
		validate(readme, checkResult);
	} catch (err) {
		_logger2.default.error(err.toString());
	}
}; /**
    * External dependencies
    */


function validate(readme, cb) {
	var options = {
		url: 'https://wordpress.org/plugins/about/validator/',
		form: {
			readme_contents: readme, // eslint-disable-line camelcase
			text: '1',
			submit: 'Validate!'
		}
	};

	_request2.default.post(options, cb);
}

function checkResult(err, resp, body) {
	if (err) {
		return _logger2.default.error(err.message);
	}

	if (200 !== resp.statusCode) {
		return _logger2.default.error('Validator responded with code ' + resp.statusCode);
	}

	var $ = _cheerio2.default.load(body);
	var collect = function collect(selector) {
		var notes = [];
		if ($(selector).length) {
			$(selector).each(function (k, li) {
				notes.push($(li).text());
			});
		}
		return notes;
	};
	var errors = collect('ul.fatal.error li');
	var warnings = collect('ul.warning.error li, ul.note.error li');

	if (errors.length) {
		return _logger2.default.error(errors.join('\n'));
	}

	if (warnings.length) {
		_logger2.default.warning(['Found ' + warnings.length + ' warning' + (warnings.length > 1 ? 's' : '') + ':', ''].concat(warnings).concat(['', 'Warning is not a blocker and can be pushed to wp.org without error']).join('\n'));
	} else {
		_logger2.default.success('Your readme.txt looks good.');
	}
}
module.exports = exports['default'];