'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _util = require('util');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _readChunk = require('read-chunk');

var _readChunk2 = _interopRequireDefault(_readChunk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * External dependencies
 */
var pluginHeaders = {
	Name: 'Plugin Name',
	PluginURI: 'Plugin URI',
	Version: 'Version',
	Description: 'Description',
	Author: 'Author',
	AuthorURI: 'Author URI',
	TextDomain: 'Text Domain',
	DomainPath: 'Domain Path',
	Network: 'Network',
	License: 'License',
	LicenseURI: 'License URI'
};

var themeHeaders = {
	Name: 'Theme Name',
	ThemeURI: 'Theme URI',
	Version: 'Version',
	Description: 'Description',
	Author: 'Author',
	AuthorURI: 'Author URI',
	Template: 'Template',
	Status: 'Status',
	Tags: 'Tags',
	TextDomain: 'Text Domain',
	DomainPath: 'Domain Path',
	License: 'License',
	LicenseURI: 'License URI'
};

var headers = {
	plugin: pluginHeaders,
	theme: themeHeaders
};

function getFileData(filepath) {
	var context = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'plugin';

	if (!filepath) {
		throw new Error('Missing plugin main file. Specify it via --file or define `files.main` in .wpt.yml.');
	}

	var pathParsed = _path2.default.parse(filepath);
	if ('' === pathParsed.dir) {
		pathParsed.dir = '.';
		filepath = _path2.default.format(pathParsed);
	}

	if (!_fs2.default.existsSync(filepath)) {
		throw new Error('File ' + filepath + ' does not exist.');
	}

	var buf = _readChunk2.default.sync(filepath, 0, 8192);
	return headerData(buf, context);
}

function headerData(buf, context) {
	var str = buf.toString('utf8').replace(/\r/, '\n');
	var header = headers[context] ? (0, _util._extend)({}, headers[context]) : (0, _util._extend)({}, pluginHeaders);

	for (var k in header) {
		var matches = str.match(new RegExp('^[ \t/*#@]*' + header[k] + ':(.*)$', 'mi')) || [];

		header[k] = matches[1] ? clean(matches[1]) : '';
	}

	return header;
}

function clean(str) {
	return str.replace(/\s*(?:\*\/|\?>).*/, '').trim();
}

exports.default = {
	headers: headers,
	getFileData: getFileData
};
module.exports = exports['default'];