'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }(); /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          * External dependencies
                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          */


/**
 * Internal dependencies
 */


var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _logger = require('./logger');

var _logger2 = _interopRequireDefault(_logger);

var _string = require('./string');

var _string2 = _interopRequireDefault(_string);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function parse(input) {
	var _parseBlock = parseBlock(input),
	    _parseBlock2 = _slicedToArray(_parseBlock, 5),
	    title = _parseBlock2[1],
	    _meta = _parseBlock2[2],
	    desc = _parseBlock2[3],
	    rest = _parseBlock2[4];

	var meta = parseMetaBlock(_meta);
	var sections = parseSections(rest);

	return {
		title: title,
		desc: desc,
		meta: meta,
		sections: sections
	};
}

function getContent() {
	var candidates = ['readme.txt', 'README.txt'];

	var content = '';
	candidates.forEach(function (c) {
		if (content) {
			return content;
		}

		var f = _path2.default.resolve(process.cwd(), c);
		if (_fs2.default.existsSync(f)) {
			content = _fs2.default.readFileSync(f, 'utf8');
		}
	});

	return content;
}

function getChangelog(version) {
	var content = getContent();
	var parsed = parse(content);

	var changelog = '';
	for (var i = 0; i < parsed.sections.length; i++) {
		if ('Changelog' === parsed.sections[i].heading) {
			var sub = parsed.sections[i].subsections || [];
			if (sub[0] && version === sub[0].heading) {
				changelog = sub[0].body;
			}
			break;
		}
	}

	if (!changelog) {
		throw new Error('Missing changelog for ' + version + ' in readme.txt. Or ' + ('latest changelog in readme.txt is not ' + version + '.'));
	}

	return changelog;
}

function checkVersion(versionInMainFile) {
	var content = getContent();
	var parsed = parse(content);

	if ('trunk' === parsed.meta['Stable tag'].trim().toLowerCase()) {
		_logger2.default.warning('Stabe tag in readme.txt is "trunk" instead of ' + versionInMainFile + '.');
	} else if (parsed.meta['Stable tag'] !== versionInMainFile) {
		throw new Error('Version in main file (' + versionInMainFile + ') does not match with stable tag in readme.txt (' + parsed.meta['Stable tag'] + ').');
	}
}

function parseBlock(input) {
	var re = /^=== (.+?) ===\n([\s\S]+?)\n\n([\s\S]+?)\n([\s\S]+)/;
	var matches = input.match(re);

	if (arrlen(matches) < 5) {
		throw new Error('Malformed metadata block');
	}

	return matches;
}

function parseSections(input) {
	var re = /(?:^|\n)== ([\s\S]+?) ==\n([\s\S]+?)(?=\n== |$)/g;
	var sections = _string2.default.matchAll(input, re);
	var results = [];

	if (!arrlen(sections)) {
		throw new Error('Failed to parse sections');
	}

	sections.forEach(function (section) {
		if (!arrlen(section)) {
			throw new Error('Failed to parse a single section');
		}

		var _section = _slicedToArray(section, 3),
		    heading = _section[1],
		    content = _section[2];

		var body = content.trim();
		var substr = body;

		var matches = body.match(/^(\s*[^=][\s\S]+?)(?=\n=|$)([\s\S]*$)/);
		if (arrlen(matches) >= 3) {
			var _matches = _slicedToArray(matches, 3);

			body = _matches[1];
			substr = _matches[2];
		} else {
			body = null;
		}

		var subsections = parseSubSections(substr);

		results.push({
			heading: heading,
			body: body,
			subsections: subsections
		});
	});

	return results;
}

function parseSubSections(substr) {
	var results = [];
	var re = /(?:^|\n)= ([\s\S]+?) =\n([\s\S]+?)(?=\n= |$)/g;
	var matches = _string2.default.matchAll(substr, re);

	if (!arrlen(matches)) {
		return results;
	}

	matches.forEach(function (subsection) {
		var _subsection = _slicedToArray(subsection, 3),
		    h = _subsection[1],
		    b = _subsection[2];

		var _ref = [h.trim(), b.trim()],
		    heading = _ref[0],
		    body = _ref[1];


		results.push({ heading: heading, body: body });
	});

	return results;
}

function parseMetaBlock(input) {
	var meta = {
		Contributors: null,
		Tags: null,
		'Requires at least': null,
		'Tested up to': null,
		'Stable tag': null,
		License: null,
		'License URI': null
	};
	input.split('\n').forEach(function (line) {
		var metaMatches = line.match(/^(.+?):\s+(.+)$/);
		if (arrlen(metaMatches) < 3) {
			throw new Error('Parse error meta block');
		}

		var _metaMatches = _slicedToArray(metaMatches, 3),
		    k = _metaMatches[1],
		    v = _metaMatches[2];

		meta[k] = v;
	});
	meta.Contributors = metaWithList(meta.Contributors);
	meta.Tags = metaWithList(meta.Tags);

	return meta;
}

function metaWithList(data) {
	return !!data ? data.split(/\s*,\s*/).filter(notEmpty) : [];
}

function notEmpty(s) {
	return !!s;
}

function arrlen(arr) {
	return Array.isArray(arr) ? arr.length : 0;
}

exports.default = {
	parse: parse,
	getContent: getContent,
	getChangelog: getChangelog,
	checkVersion: checkVersion
};
module.exports = exports['default'];